#!/bin/bash

## the raw trva.svm will be split into 2 parts: {tr + va data for previois model}|{tr + va data for cf learning}
rest_tr=75  # {rest_va}% raw trva.svm for final model training
neg_reward=0.001
replay=1

## set random seed for reproducing
get_seeded_random()
{
  seed="$1"
  openssl enc -aes-256-ctr -pass pass:"$seed" -nosalt \
    </dev/zero 2>/dev/null
}

root=`realpath $1`
data_dir=`basename $root`"_bandit"
mkdir -p $data_dir

## link data into current dir and shuf trva.svm; te.svm may be kept full-label and reserved for online simulation
cd ./$data_dir
ln -sf ${root}/label.svm ./label.svm
ln -sf ${root}/s1.svm ./pv.svm
ln -sf ${root}/s2.svm ./rest.svm
ln -sf ${root}/s3.svm ./te.svm

## split data
num_item=`wc -l label.svm | cut -d' ' -f1`
num_pv=`wc -l pv.svm | cut -d' ' -f1`
num_rest=`wc -l rest.svm | cut -d' ' -f1`
num_te=`wc -l te.svm | cut -d' ' -f1`
num_rest_tr=$(echo "scale=0;${num_rest}*${rest_tr}/100" | bc -l)
num_rest_va=$(echo "scale=0;${num_rest}-${num_rest_tr}" | bc -l)
echo ${num_item} "("$num_pv $num_rest_tr $num_rest_va ${num_te}")"
head -n ${num_rest_tr} rest.svm > rest_tr.svm
tail -n ${num_rest_va} rest.svm > rest_va.svm

## replay function
replay_data()
{
    for j in `seq 1 ${replay}`
    do
        echo "python ../pv_proc.py ./pv.svm $num_item $neg_reward $j"
    done
}

## replay data for pv model training, uniformly sample them to create bandit data.
replay_data | xargs -0 -d '\n' -P 8 -I {} sh -c {}
cat pv.uniform.svm.part* > pv.replay${replay}.uniform.svm
cat pv.uniform.Rn.part* > pv.replay${replay}.uniform.Rn
cat pv.uniform.nzinfo.part* > pv.replay${replay}.uniform.nzinfo
rm pv.*.part*
