
import numpy as np
import scipy as sp
from scipy.sparse import csr_matrix
import os, sys
from utils import uniform, dump_svm
from tqdm import trange
from sklearn.datasets import dump_svmlight_file, load_svmlight_file


data_file = sys.argv[1]
n = int(sys.argv[2])
neg_reward = float(sys.argv[3])
seed = int(sys.argv[4])
np.random.seed(seed)

bsize = 8192
svm_file = data_file[:-4]+'.uniform.svm.part%d'%seed
rn_file = data_file[:-4]+'.uniform.Rn.part%d'%seed
nz_file = data_file[:-4]+'.uniform.nzinfo.part%d'%seed

with open(data_file, 'rb') as fin, \
        open(rn_file, 'w') as frout, \
        open(nz_file, 'w') as fnout:
    X, y = load_svmlight_file(fin, multilabel=True)
    m = X.shape[0]
    idx_out, propensity_out, value_out = [], [], []
    for i in trange(0, len(y), bsize):
        tmp_y = y[i:i+bsize]
        idx, propensity = uniform(len(tmp_y), n, 1)
        value = np.array([np.isin(idx[j, :], tmp_y[j]) for j in range(len(tmp_y))])
        idx_out.append(idx.reshape(-1,1))
        propensity_out.append(propensity.reshape(-1,1))
        value_out.append(value.reshape(-1,1))

    idx_out = np.vstack(idx_out).ravel()
    y = csr_matrix((np.ones(m), (np.arange(m), idx_out)), shape=(m,n))
    propensity_out = np.vstack(propensity_out).ravel()
    value_out = np.vstack(value_out).astype(np.float).ravel()
    value_out[value_out != 1] = neg_reward
    Rn = value_out / propensity_out

    dump_svmlight_file(X, y, svm_file, multilabel=True)
    for i in range(value_out.shape[0]):
        frout.write('%.16f\n'%(Rn[i]))
        fnout.write('%.16f\n'%(Rn[i]))
