#!/bin/bash

cd ./c_funs
make clean all
cd ../

CGmax=30
net_u='Linear'
net_v='Linear'
optim='NewtonCG'

# params
ml1m_params="0.00390625_0.0625_128_-4_12"
ml10m_params="0.25_0.0625_128_-1_26"

task(){
# Set up train command
for d in 'ml1m' 'ml10m'
do
	eval params="\${${d}_params}"
	l=`echo ${params} | cut -d'_' -f1`
	w=`echo ${params} | cut -d'_' -f2`
	k=`echo ${params} | cut -d'_' -f3`
	r=`echo ${params} | cut -d'_' -f4`
	t=`echo ${params} | cut -d'_' -f5`
	log_path="${d}/best_params"
	for i in 'rest' 'te'
	do
	    train_cmd="CUDA_VISIBLE_DEVICES=-1 python ./train.py --save_pq"
	    train_cmd="${train_cmd} --u_set ./$d/tr.svm"
	    train_cmd="${train_cmd} --v_set ./$d/label.svm"
	    train_cmd="${train_cmd} --val_set ./$d/$i.svm"
	    #train_cmd="${train_cmd} --R tr.Rn --weights tr.nzinfo"
	    train_cmd="${train_cmd} --CGmax ${CGmax}"
	    train_cmd="${train_cmd} --net_u ${net_u}"
	    train_cmd="${train_cmd} --net_v ${net_v}"
	    
	    # Print out all parameter pair
	    cmd="${train_cmd} -k ${k} -r ${r}"
	    cmd="${cmd} --lambda ${l}"
	    cmd="${cmd} --omega ${w}"
	    cmd="${cmd} -t ${t}"
	    cmd="${cmd} --log ${log_path}/${l}_${w}_${k}_${r}_${t}_${i}.log"
	    cmd="${cmd} --model ${log_path}/${l}_${w}_${k}_${r}_${t}_${i}.model"
	    echo "${cmd}"
	done
done
}


# Check command
task
wait


# Run
task | xargs -0 -d '\n' -P 4 -I {} sh -c {}
